@@ -190,45 +190,38 @@ pub fn for_data(filename: &str) -> CliResult<(Option<String>, InferenceFact)> {
 }
 
 pub fn for_npz(npz: &mut ndarray_npy::NpzReader<fs::File>, name: &str) -> CliResult<Tensor> {
-    fn rewrap<T: Datum>(array: tract_ndarray::ArrayD<T>) -> Tensor {
-        let shape = array.shape().to_vec();
-        unsafe {
-            let vec = array.into_raw_vec();
-            tract_core::ndarray::ArrayD::from_shape_vec_unchecked(shape, vec).into_tensor()
-        }
-    }
     if let Ok(t) = npz.by_name::<tract_ndarray::OwnedRepr<f32>, tract_ndarray::IxDyn>(name) {
-        return Ok(rewrap(t));
+        return Ok(t.into_tensor());
     }
     if let Ok(t) = npz.by_name::<tract_ndarray::OwnedRepr<f64>, tract_ndarray::IxDyn>(name) {
-        return Ok(rewrap(t));
+        return Ok(t.into_tensor());
     }
     if let Ok(t) = npz.by_name::<tract_ndarray::OwnedRepr<i8>, tract_ndarray::IxDyn>(name) {
-        return Ok(rewrap(t));
+        return Ok(t.into_tensor());
     }
     if let Ok(t) = npz.by_name::<tract_ndarray::OwnedRepr<i16>, tract_ndarray::IxDyn>(name) {
-        return Ok(rewrap(t));
+        return Ok(t.into_tensor());
     }
     if let Ok(t) = npz.by_name::<tract_ndarray::OwnedRepr<i32>, tract_ndarray::IxDyn>(name) {
-        return Ok(rewrap(t));
+        return Ok(t.into_tensor());
     }
     if let Ok(t) = npz.by_name::<tract_ndarray::OwnedRepr<i64>, tract_ndarray::IxDyn>(name) {
-        return Ok(rewrap(t));
+        return Ok(t.into_tensor());
     }
     if let Ok(t) = npz.by_name::<tract_ndarray::OwnedRepr<u8>, tract_ndarray::IxDyn>(name) {
-        return Ok(rewrap(t));
+        return Ok(t.into_tensor());
     }
     if let Ok(t) = npz.by_name::<tract_ndarray::OwnedRepr<u16>, tract_ndarray::IxDyn>(name) {
-        return Ok(rewrap(t));
+        return Ok(t.into_tensor());
     }
     if let Ok(t) = npz.by_name::<tract_ndarray::OwnedRepr<u32>, tract_ndarray::IxDyn>(name) {
-        return Ok(rewrap(t));
+        return Ok(t.into_tensor());
     }
     if let Ok(t) = npz.by_name::<tract_ndarray::OwnedRepr<u64>, tract_ndarray::IxDyn>(name) {
-        return Ok(rewrap(t));
+        return Ok(t.into_tensor());
     }
     if let Ok(t) = npz.by_name::<tract_ndarray::OwnedRepr<bool>, tract_ndarray::IxDyn>(name) {
-        return Ok(rewrap(t));
+        return Ok(t.into_tensor());
     }
     bail!("Can not extract tensor from {}", name);
 }
